Produces basic, and hopefully useful, summary statistics on censored data.
censummary(obs, censored, groups = NULL, ...)censummary.default(obs, censored, ...)
censummary.factor(obs, censored, groups, ...)
censummary.numeric(obs, censored, groups, ...)
An object of class "censummary" containing summary statistics,
or a list of such objects if grouped.
A numeric vector of observations.
A logical vector indicating TRUE where an observation in obs is censored (a less-than value), and FALSE otherwise.
Optional grouping variable (factor or numeric) used to compute summaries by subset.
Additional arguments passed to methods.
This is a generic function with methods for numeric vectors and grouped data.
The generic function dispatches to methods based on the presence
and type of groups:
censummary.defaultBasic summary for numeric vectors.
censummary.factorSummary grouped by a factor variable.
censummary.numericSummary grouped by a numeric grouping variable (converted to factor).
Helsel, Dennis R. (2005). Nondetects and Data Analysis: Statistics for Censored Environmental Data. John Wiley and Sons, USA, NJ.